@@ -10,9 +10,11 @@ class HeartbeatHandler(tornado.web.RequestHandler):
     def get(self):
         if self.circuit_breaker.is_tripped():
             self.set_status(503)
+            status_message = "Circuit Breaker Tripped"
         else:
             self.set_status(200)
+            status_message = "OK"
 
         self.write("Mallory " + mallory.Version + "\n")
-        self.write("OK")
+        self.write(status_message)
         self.finish()
